pub struct AgentExecutor<'a> { /* private fields */ }Expand description
Configurable agent loop with tool calling support.
Usage
let declarations = vec![FunctionDeclaration {
name: "search".into(),
description: "Search the web".into(),
parameters: Some(json!({"type": "object", "properties": {"q": {"type": "string"}}})),
}];
let handler: TextToolHandler = Arc::new(|name, _args| {
FunctionResponse { name: name.to_owned(), response: json!({"results": []}) }
});
let executor = AgentExecutor::new(provider, declarations, handler);
let messages = vec![ChatMessage::user("Search for Rust tutorials")];
let result = executor.run(messages).await?;
println!("{}", result.content);Implementations
Sourceimpl<'a> AgentExecutor<'a>
impl<'a> AgentExecutor<'a>
Sourcepub fn new(
provider: &'a dyn LlmProvider,
declarations: Vec<FunctionDeclaration>,
tool_handler: TextToolHandler,
) -> Self
pub fn new( provider: &'a dyn LlmProvider, declarations: Vec<FunctionDeclaration>, tool_handler: TextToolHandler, ) -> Self
Create a new agent executor with default settings (max_turns=10)
Sourcepub fn with_max_turns(self, max_turns: u32) -> Self
pub fn with_max_turns(self, max_turns: u32) -> Self
Set the maximum number of turns (clamped to ceiling of 50)
Sourcepub fn with_on_turn(self, callback: OnTurnCallback) -> Self
pub fn with_on_turn(self, callback: OnTurnCallback) -> Self
Set an observability callback invoked after each turn
Sourcepub async fn run(
&self,
initial_messages: Vec<ChatMessage>,
) -> Result<AgentResult, RunnerError>
pub async fn run( &self, initial_messages: Vec<ChatMessage>, ) -> Result<AgentResult, RunnerError>
Run the agent loop with the given initial messages.
Errors
Returns RunnerError if any provider.complete() call fails.