Module prompt

Module prompt 

Prompt construction from ChatMessage sequences

Structs

PreparedPrompt
Prompt with materialized image files for CLI runners

Functions

build_prompt
Build a single prompt string from a slice of chat messages
build_user_prompt
Build a prompt string from non-system messages only
extract_system_message
Extract the content of the first system message, if any
prepare_prompt
Build a prompt with images materialized to temp files
prepare_user_prompt
Build a prompt with images materialized, excluding system messages
warn_images_via_tempfile
Log a warning when images are present but the runner cannot process them