pub struct LlmCapabilities(/* private fields */);Expand description
LLM provider capability flags using bitflags for efficient storage
Indicates which features a provider supports. Used by the system to select appropriate providers and configure request handling.
Implementations
Sourceimpl LlmCapabilities
impl LlmCapabilities
Sourcepub const FUNCTION_CALLING: Self
pub const FUNCTION_CALLING: Self
Provider supports function/tool calling
Sourcepub const SYSTEM_MESSAGES: Self
pub const SYSTEM_MESSAGES: Self
Provider supports system messages
Sourcepub const SDK_TOOL_CALLING: Self
pub const SDK_TOOL_CALLING: Self
Provider supports SDK-managed tool calling (tool loop handled by SDK, not by caller)
Sourcepub const TEMPERATURE: Self
pub const TEMPERATURE: Self
Provider supports temperature parameter
Sourcepub const MAX_TOKENS: Self
pub const MAX_TOKENS: Self
Provider supports max_tokens parameter
Sourceimpl LlmCapabilities
impl LlmCapabilities
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<Self>
pub const fn from_bits(bits: u16) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> Self
pub const fn from_bits_truncate(bits: u16) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> Self
pub const fn from_bits_retain(bits: u16) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl LlmCapabilities
impl LlmCapabilities
Sourcepub const fn iter(&self) -> Iter<LlmCapabilities>
pub const fn iter(&self) -> Iter<LlmCapabilities>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<LlmCapabilities>
pub const fn iter_names(&self) -> IterNames<LlmCapabilities>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl LlmCapabilities
impl LlmCapabilities
Sourcepub const fn full_featured() -> Self
pub const fn full_featured() -> Self
Create capabilities for a full-featured provider (like Gemini Pro)
Sourcepub const fn supports_streaming(&self) -> bool
pub const fn supports_streaming(&self) -> bool
Check if streaming is supported
Sourcepub const fn supports_function_calling(&self) -> bool
pub const fn supports_function_calling(&self) -> bool
Check if function calling is supported
Sourcepub const fn supports_vision(&self) -> bool
pub const fn supports_vision(&self) -> bool
Check if vision is supported
Sourcepub const fn supports_json_mode(&self) -> bool
pub const fn supports_json_mode(&self) -> bool
Check if JSON mode is supported
Sourcepub const fn supports_system_messages(&self) -> bool
pub const fn supports_system_messages(&self) -> bool
Check if system messages are supported
Sourcepub const fn supports_sdk_tool_calling(&self) -> bool
pub const fn supports_sdk_tool_calling(&self) -> bool
Check if SDK-managed tool calling is supported
Sourcepub const fn supports_temperature(&self) -> bool
pub const fn supports_temperature(&self) -> bool
Check if temperature parameter is supported
Sourcepub const fn supports_max_tokens(&self) -> bool
pub const fn supports_max_tokens(&self) -> bool
Check if max_tokens parameter is supported